@@ -95,20 +95,17 @@ def poll_remotes():
     return datasets
 
 
-datasets = poll_remotes()
+#datasets = poll_remotes()
 
+class Remotes:
+    def __init__(self):
+        self._datasets = None
 
-def download(datasets=datasets):
-    """
-    Download all known remotes
-    """
+    @property
+    def datasets(self):
+        if self._datasets is None:
+            self._datasets = poll_remotes()
+        return self._datasets
+
+datasets = Remotes()
 
-    names = list(datasets.keys())
-    names.sort()
-    for name in names:
-        print(name)
-        example = datasets[name]
-        try:
-            example.download()
-        except:
-            print("Example not downloaded: {}".format(name))
